package com.jkcredit.invoice.credit.custInterface;

import com.jkcredit.invoice.common.DataResult;

public interface NoCarInterService {

    //无车 车辆备案接口
    DataResult customerCarRec(String appKey, String api, String data, String requestid);

    //无车 车辆备案查询接口
    DataResult customeRecUpperQuery(String appKey, String api, String data, String requestid);

    //无车 实时运单开始指令
    DataResult noCarBillStart(String appKey, String api, String data, String requestid);

    //无车 实时运单结束指令
    DataResult noCarBillEnd(String appKey, String api, String data, String requestid);

    //无车 历史运单开始指令
    DataResult noCarHisWaybillStart(String appKey, String api, String data, String requestid);

    //无车 历史运单结束指令
    DataResult noCarHisWaybillEnd(String appKey, String api, String data, String requestid);

    //无车  运单号查询发票数据
    DataResult noCarVoiceQuery(String appKey, String api, String data, String requestid);

    //无车  获取未查询过发票的运单编号
    DataResult noCarNoVoiceQuery(String appKey, String api, String data, String requestid);

    //无车 账户余额查询接口
    DataResult balanceQuery(String appKey, String api, String data, String requestid);
}
